import React from 'react'
import { ComponentStory, ComponentMeta } from '@storybook/react'

import { default as MultiAreaChart } from '../../components/MultiAreaChart'

export default {
  title: 'Charts/MultiAreaChart',
  component: MultiAreaChart,
} as ComponentMeta<typeof MultiAreaChart>

const Template: ComponentStory<typeof MultiAreaChart> = (args) => 
  <div style={{ width: '100%', height: '600px' }}><MultiAreaChart {...args} /></div>

const CustomTooltip = ({ active, payload, label }: any) => {
  if (active && payload && payload.length) {
    const total = parseInt(payload[0].payload['sun']) + parseInt(payload[0].payload['wind_land']) + parseInt(payload[0].payload['wind_sea'])
    const consumption = Math.floor(payload[0].payload['consumption'])
    const surplus = total - consumption
    const surplusStyle = surplus < 0 ? {color: 'red'} : {color: 'green'}
    const surplusComponent = <span style={surplusStyle}>{surplus}</span>
    return (
      <div style={{ background: '#fefefe', padding: 8, borderRadius: 4 }}>
        <b>{label}</b>
        <br/>
        {`Sol: ${payload[0].payload['sun']}`}
        <br/>
        {`Landvind: ${payload[0].payload['wind_land']}`}
        <br/>
        {`Havvind: ${payload[0].payload['wind_sea']}`}
        <br/>
        <b>{`Total: ${total}`}</b>
        <hr/>
        {`Forbrug: ${Math.floor(payload[0].payload['consumption'])}`}
        <hr/>
        Overskud: {surplusComponent}
      </div>
    )
  }
  return null
}

export const EnergyConsumption = Template.bind({});
EnergyConsumption.args = {
  legend: {
    show: true
  },
  tooltip: {
    active: true,
    customTooltip: <CustomTooltip />
  },
  data:{
    xAxis: {
      values: ["Jan","Feb","Mar","Apr","Maj","Jun", "Jul", "Aug", "Sep", "Okt", "Nov", "Dec"],
    },
    areas: [
      {
        label: "Underskud",
        key: "consumption",
        stackIndex: 3,
        stroke: "red",
        fill: "red",
        opacity: 0.5,
        values: [920,900,800,744,744,1080,584,856,754,754,666,1000],
        dot: false,
      },
      {
        label: "Sol",
        key: "sun",
        stackIndex: 2,
        stroke: "#5F9EA0",
        fill: "#5F9EA0",
        opacity: 1,
        values: [100,200,100,300,400,200,150,250,454,212,242,111],
        dot: false,
      },
      {
        label: "Landvind",
        key: "wind_land",
        stackIndex: 2,
        stroke: "#6689CC",
        fill: "#6669CC",
        opacity: 1,
        values: [423,546,344,233,452,112,424,553,222,334,232,124],
        dot: false,
      },
      {
        label: "Havvind",
        key: "wind_sea",
        stackIndex: 2,
        stroke: "dodgerblue",
        fill: "dodgerblue",
        opacity: 1,
        values: [124,434,238,296,356,322,153,427,323,632,434,333],
        dot: false,
      },
    ],
    lines: [
      {
        label: "Forbrug",
        key: "consumption",
        stroke: "black",
        width: 2,
        opacity: 1,
        values: [920,900,800,744,744,1080,584,856,754,754,666,1000],
        dot: true,
      },
    ],
  }, 
}
